==> haskell-contravariant-extras-0.3.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-LS2OolzRbnV1PjJqBFISq0
key: contravariant-extras-0.3.4-LS2OolzRbnV1PjJqBFISq0
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: c96935a4c21d6fafe7b7f6257d5a5809
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-LS2OolzRbnV1PjJqBFISq0
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV template-haskell-2.14.0.0
    tuple-th-0.2.5-GwUCeaN8vvJEBlSQcMUthO
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.4-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
key: contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: d734b9872fac7bbb18dc8d5362183264
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    template-haskell-2.14.0.0 tuple-th-0.2.5-GwUCeaN8vvJEBlSQcMUthO
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
